summaryrefslogtreecommitdiffstats
path: root/kopete/protocols/meanwhile/meanwhilesession.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/protocols/meanwhile/meanwhilesession.cpp')
-rw-r--r--kopete/protocols/meanwhile/meanwhilesession.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/kopete/protocols/meanwhile/meanwhilesession.cpp b/kopete/protocols/meanwhile/meanwhilesession.cpp
index 5f367540..3b880932 100644
--- a/kopete/protocols/meanwhile/meanwhilesession.cpp
+++ b/kopete/protocols/meanwhile/meanwhilesession.cpp
@@ -426,7 +426,7 @@ void MeanwhileSession::syncContactsToServer()
if (contactgroup->type() == Kopete::Group::TopLevel) {
stgroup = topstgroup;
} else {
/* tqfind (or create) a matching sametime list group */
stgroup = mwSametimeList_findGroup(list,
contactgroup->displayName().ascii());
if (stgroup == 0L) {
@@ -555,10 +555,10 @@ TQString MeanwhileSession::getNickName(struct mwLoginInfo *logininfo)
TQString MeanwhileSession::getNickName(TQString name)
{
- int index = name.tqfind(" - ");
+ int index = name.find(" - ");
if (index != -1)
name = name.remove(0, index + 3);
- index = name.tqfind('/');
+ index = name.find('/');
if (index != -1)
name = name.left(index);
@@ -426,7 +426,7 @@ void MeanwhileSession::syncContactsToServer()
stgroup = topstgroup;
} else {
- /* tqfind (or create) a matching sametime list group */
+ /* find (or create) a matching sametime list group */
stgroup = mwSametimeList_findGroup(list,
contactgroup->displayName().ascii());